# Flamiche
Fast, unopinionated, minimalist ASGI web framework for [Python](https://www.python.org/).

[![Build Status](https://github.com/aryaniyaps/flamiche/workflows/tests/badge.svg)](https://github.com/aryaniyaps/flamiche/actions)
[![PyPI version](https://img.shields.io/pypi/v/flamiche?color=%2334D058)](https://pypi.org/project/flamiche)
[![codecov](https://codecov.io/gh/aryaniyaps/flamiche/branch/main/graph/badge.svg?token=BDORVBQP7S)](https://codecov.io/gh/aryaniyaps/flamiche)
